function write_MatIDA_paramfile(anlsdir,fname,allfloat,varargin)
% it can handle lists of numbers, strings and single numbers
% see plot_AIRframe_pushovers.m for an example.
% 
% Created 29/Oct/2008, Copyright (c) 2008 by D.Vamvatsikos
% Updated 01/Jun/2009: Added the ability to write 2D arrays
%         as nested tcl lists. Also added parameter allfloat
%         If allfloat==1 then even integer values are written 
%         as floats in tcl output.
% Updated 04/Oct/2010: Fixed the code creating the 2D arrays as it would
%         erroneously reproduce the entire matlab-array in each row
%         of the output tcl-array!
%
% Note: I am making a point to pass integers as integers and floats as
% floats. The reason is that some variables in openSEES need to be integers
% for example node numbers, or any kind of for-loop counters. For example
% the number of stories or bays is a typical case. Passing them as floats
% causes trouble.
% NOTE FOR POSSIBLE UPGRADE:
% Sometimes I want 1.0 to actually be passed to opensees as a float 1.0,
% rather than 1 (which is the default here). I need some way to communicate
% this preference to the present routine. Probably if it is written as a
% character string, this will be immediately taken care of!! No upgrade
% needed then!

%warning('allfloat var has been added. Older uses of this routine might be broken!!')

if isempty(allfloat), allfloat==0; end
if mod(nargin-3,2)==1, error('need pairs of parameters and values'); end
if isempty(fname),
   fname='MatIDA_paramfile.tcl';
end

fout=fopen(fullfile(anlsdir,fname),'w');
for i=1:(nargin-3)/2
   pname=varargin{2*i-1};
   pvalue=varargin{2*i};
   ndim=size(pvalue);
   if ischar(pvalue)
      fprintf(fout,['set ' pname  ' "' sprintf('%s',pvalue) '"\n']);
   elseif all(ndim>1)
      % this is a 2D matrix
      if ~allfloat && all(fix(pvalue)==pvalue)
         fprintf(fout,['set ' pname ' {']);
         for j=1:ndim(1)
            fprintf(fout,['   {' sprintf('%d ',pvalue(j,:)) '}\n']);
         end
         fprintf(fout,'     }\n');
      else
         fprintf(fout,['set ' pname ' {']);
         for j=1:ndim(1)
            fprintf(fout,['   {' sprintf('%8.4f ',pvalue(j,:)) '}\n']);
         end
         fprintf(fout,'     }\n');
      end
   elseif any(ndim>1)
      % this is a vector 
      % note that using isinteger does not work. The value "2" is still
      % a double in Matlab unless you declare it as int8 or something
      % similar.
      if ~allfloat && all(fix(pvalue)==pvalue)
         fprintf(fout,['set ' pname ' {' sprintf('%d ',pvalue) '}\n']);
      else
         fprintf(fout,['set ' pname ' {' sprintf('%8.4f ',pvalue) '}\n']);
      end
   else
      if ~allfloat && fix(pvalue)==pvalue
         fprintf(fout,['set ' pname sprintf(' %d ',pvalue) '\n']);
      else
         fprintf(fout,['set ' pname sprintf(' %8.4f ',pvalue) '\n']);
      end
   end
end
fclose(fout);
